@@ -45,17 +45,18 @@
 #include "views/manager/kpViewManager.h"
 
 #include <math.h>
+#include <kexiv2/kexiv2.h>
 
 #include <qcolor.h>
 #include <qimage.h>
 #include <QMimeDatabase>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 #include <kimageio.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kmimetype.h>  // TODO: isn't this in KIO?
+#include <kmimetype.h>
 
 //---------------------------------------------------------------------
 
@@ -84,7 +85,7 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
                                      kpDocumentMetaInfo *metaInfo)
 {
 #if DEBUG_KP_DOCUMENT
-    kDebug () << "kpDocument::getPixmapFromFile(" << url << "," << parent << ")";
+    qCDebug(kpLogDocument) << "kpDocument::getPixmapFromFile(" << url << "," << parent << ")";
 #endif
 
     if (saveOptions)
@@ -134,9 +135,9 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
             saveOptions->setMimeType (detectedMimeType);
 
     #if DEBUG_KP_DOCUMENT
-        kDebug () << "\ttempFile=" << tempFile;
-        kDebug () << "\tmimetype=" << detectedMimeType;
-        kDebug () << "\tsrc=" << url.path ();
+        qCDebug(kpLogDocument) << "\ttempFile=" << tempFile;
+        qCDebug(kpLogDocument) << "\tmimetype=" << detectedMimeType;
+        qCDebug(kpLogDocument) << "\tsrc=" << url.path ();
     #endif
 
         if (detectedMimeType.isEmpty ())
@@ -161,6 +162,10 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
         //       on the extension, but findByContent() correctly detects
         //       it as a PNG.
         image = QImage (tempFile);
+
+        KExiv2Iface::KExiv2 exif(tempFile);
+        exif.rotateExifQImage(image, exif.getImageOrientation());
+
         KIO::NetAccess::removeTempFile (tempFile);
     }
 
@@ -174,7 +179,7 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
     }
 
 #if DEBUG_KP_DOCUMENT
-    kDebug () << "\tpixmap: depth=" << image.depth ()
+    qCDebug(kpLogDocument) << "\tpixmap: depth=" << image.depth ()
                 << " hasAlphaChannel=" << image.hasAlphaChannel ()
                 << endl;
 #endif
@@ -195,7 +200,7 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
 void kpDocument::openNew (const QUrl &url)
 {
 #if DEBUG_KP_DOCUMENT
-    kDebug () << "kpDocument::openNew (" << url << ")";
+    qCDebug(kpLogDocument) << "kpDocument::openNew (" << url << ")";
 #endif
 
     m_image->fill(QColor(Qt::white).rgb());
@@ -227,7 +232,7 @@ void kpDocument::openNew (const QUrl &url)
 bool kpDocument::open (const QUrl &url, bool newDocSameNameIfNotExist)
 {
 #if DEBUG_KP_DOCUMENT
-    kDebug () << "kpDocument::open (" << url << ")";
+    qCDebug(kpLogDocument) << "kpDocument::open (" << url << ")";
 #endif
 
     kpDocumentSaveOptions newSaveOptions;
