@@ -30,7 +30,7 @@
 #define kpToolEnvironment_H
 
 
-#include <kpEnvironmentBase.h>
+#include "environments/kpEnvironmentBase.h"
 
 
 class QActionGroup;
