@@ -342,6 +342,7 @@ private:
 private slots:
     void slotOpen ();
     void slotOpenRecent (const QUrl &url);
+    void slotRecentListCleared();
 
 #if HAVE_KSANE
     void slotScan ();
@@ -558,11 +559,11 @@ public:
                                      bool addSelCreateCmdIfSelAvail = true,
                                      bool addSelContentCmdIfSelAvail = true);
 
-private slots:
-    void slotResizeScale ();
 public slots:
     void slotCrop ();
+
 private slots:
+    void slotResizeScale ();
     void slotAutoCrop ();
     void slotFlip ();
     void slotMirror ();
@@ -576,6 +577,7 @@ private slots:
     void slotConvertToGrayscale ();
     void slotInvertColors ();
     void slotClear ();
+    void slotMakeConfidential();
     void slotMoreEffects ();
 
 
